//+--------------------------------------------------------------------------------+
//+--------------------------------------------------------------------------------+

#property copyright           "Copyright 2022, Darwinex"
#property link                "https://www.darwinex.com"
#property description         "Incremental Value at Risk (VaR) Script Example Code"
#property script_show_inputs
#property strict

//CUSTOM INCLUDE FILE - ENSURE THE FOLLOWING INCLUDE FILE IS LOCATED IN ..\[DATA_FOLDER]\MQL5\Include\Darwinex\DWEX Portfolio Risk Man Multi Position.mqh]
#include <DWEX Portfolio Risk Man Multi Position.mqh>

//INPUTS
input ENUM_TIMEFRAMES InpVaRTimeframe    = PERIOD_D1;    //Value at Risk Timeframe
input int             InpStdDevPeriods   = 21;           //Std Deviation Periods
input int             InpCorrelPeriods   = 42;           //Pearson Correlation Coeff Periods
input string          InpProposedSymbol  = "NZDJPY";     //Proposed Position
input double          InpProposedPosSize = 0.12;         //Proposed Position Size (+ve LONG / -ve SHORT)

void OnTick()
{
   CPortfolioRiskMan PortfolioRisk(InpVaRTimeframe, InpStdDevPeriods, InpCorrelPeriods);
   
//   string CurrPortAssets[]   = {"AUDCAD"};
//   double CurrPortLotSizes[] = { 0.1 };      //+ve - LONG,  -ve - SHORT 
   
   string CurrPortAssets[];
   double CurrPortLotSizes[];      //+ve - LONG,  -ve - SHORT
   
   uint positions = PositionsTotal();
   ArrayResize(CurrPortAssets,positions);
   ArrayResize(CurrPortLotSizes,positions);
   for (uint i=0; i<positions; i++)
      {
      string activo = PositionGetSymbol(i);
      PositionSelect(activo);
      double cantidad = PositionGetDouble(POSITION_VOLUME);
      long direction = PositionGetInteger(POSITION_TYPE);
      CurrPortAssets[i] = activo;
      CurrPortLotSizes[i] = direction==POSITION_TYPE_BUY? cantidad : -cantidad;
      }
      
   
   //CALCULATE THE INITIAL VaR BEFORE PROPOSED POSITION
   PortfolioRisk.CalculateVaR(CurrPortAssets, CurrPortLotSizes);  
   double currValueAtRisk = PortfolioRisk.MultiPositionVaR;
   
   //CREATE PROPOSED POSITION ARRAY AND ADD PROPOSED POSITION 
   string ProposedPortAssets[];
   double ProposedPorLotSizes[];
   ArrayResize(ProposedPortAssets, ArraySize(CurrPortAssets) + 1);
   ArrayResize(ProposedPorLotSizes, ArraySize(CurrPortLotSizes) + 1);
   
   ArrayCopy(ProposedPortAssets, CurrPortAssets);
   ArrayCopy(ProposedPorLotSizes, CurrPortLotSizes);
   
   ProposedPortAssets[ArraySize(ProposedPortAssets)-1]   = InpProposedSymbol;
   ProposedPorLotSizes[ArraySize(ProposedPorLotSizes)-1] = InpProposedPosSize;
   
   //POSITION DIAGNOSTIOCS
   string posDiagnostics = "";
   for(int i=0; i<ArraySize(ProposedPortAssets); i++)
   {
      string posType = (i==ArraySize(ProposedPortAssets)-1)?"PROPOSED":"EXISTING";
      posDiagnostics += "Pos " + IntegerToString(i) + " " + ProposedPortAssets[i] + " " + DoubleToString(ProposedPorLotSizes[i], 2) + "  (" + posType + ")\n";
   }   
   
   //CALCULATE THE PROPOSED VaR IF NEW POSITION WERE ALLOWED TO OPEN
   PortfolioRisk.CalculateVaR(ProposedPortAssets, ProposedPorLotSizes);
   double proposedValueAtRisk = PortfolioRisk.MultiPositionVaR;
   
   //CALCULATE INCREMENTAL VaR
   double incrVaR = proposedValueAtRisk - currValueAtRisk;
   
//   MessageBox(posDiagnostics + "\n" +
//              "CURRENT VaR: " + DoubleToString(currValueAtRisk, 2) + "\n" +
//              "PROPOSED VaR: " + DoubleToString(proposedValueAtRisk, 2) + "\n" +
//              "INCREMENTAL VaR: " + DoubleToString(incrVaR, 2)); 
//              
   Comment(
   "  TRADE MANAGEMENT:  ", "\n\n",
   "Value at Risk: $" + DoubleToString(currValueAtRisk, 2) + "\n" 
   "Standard Deviation: " + "\n" 
   
   );
}